Struct

TermboxCell

Description

struct TbgCell {
  /* No available fields */
}

A snapshot of a termbox cell.

A cell contains a primary Unicode code point, foreground and background attributes, and optionally an extended grapheme cluster. Values returned from tbg_terminal_get_cell() are deep copies and do not borrow memory from termbox.

Instance methods

tbg_cell_copy

Copy cell.

tbg_cell_free

Free cell.

tbg_cell_get_background

Return the cell’s background attribute.

tbg_cell_get_char

Return the cell’s primary Unicode code point.

tbg_cell_get_extended_chars

Return the extended grapheme cluster code points for cell.

tbg_cell_get_foreground

Return the cell’s foreground attribute.