Struct
TermboxCell
Description
struct TbgCell {
/* No available fields */
}
A snapshot of a termbox cell.
A cell contains a primary Unicode code point, foreground and background
attributes, and optionally an extended grapheme cluster. Values returned from
tbg_terminal_get_cell() are deep copies and do not borrow memory from termbox.